<?php

namespace Drupal\janrain_connect\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormBuilderInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Admin areas.
 */
class AdminController extends ControllerBase {

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
        $container->get('form_builder')
    );
  }

  /**
   * Constructs an AdminController object.
   *
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder.
   */
  public function __construct(FormBuilderInterface $form_builder) {
    $this->formBuilder = $form_builder;
  }

  /**
   * Manage admin areas.
   *
   * @param string $type
   *   The type of the overview form ('default' or 'sync') default to 'default'.
   *
   * @return array
   *   Default form or sync form
   */
  public function adminPage($type = 'default') {

    switch ($type) {
      case 'default':
        return $this->formBuilder->getForm('\Drupal\janrain_connect\Form\JanrainConnectSettingsForm');

      case 'sync':
        return $this->formBuilder->getForm('\Drupal\janrain_connect\Form\JanrainConnectSyncForm');

      case 'forms':
        return $this->formBuilder->getForm('\Drupal\janrain_connect\Form\JanrainConnectShowForms');

      case 'users':
        return $this->formBuilder->getForm('\Drupal\janrain_connect\Form\JanrainConnectUsersForm');

      default:
        return $this->formBuilder->getForm('\Drupal\janrain_connect\Form\JanrainConnectSettingsForm');
    }
  }

}
