<?php

namespace Drupal\janrain_connect\Service;

use Drupal\janrain_connect\Constants\JanrainConnectValidationConstants;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * JanrainConnect Validate Class.
 */
class JanrainConnectValidate {

  use StringTranslationTrait;

  /**
   * The logger factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * JanrainConnectValidate constructor.
   *
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   Logger Factory.
   */
  public function __construct(LoggerChannelFactoryInterface $logger_factory) {
    $this->logger = $logger_factory->get('janrain_connect');
  }

  /**
   * Validate response.
   *
   * @param array $response
   *   Response.
   */
  public function validateResponse(array $response) {

    $validation_messages = JanrainConnectValidationConstants::JANRAIN_CONNECT_VALIDATION_MESSAGES;

    // If not exists code or if it is not mapped log in watchdog.
    if (empty($response['code']) || empty($validation_messages[$response['code']])) {

      // Info response on watchdog.
      $this->logger->info(json_encode($response));

      return FALSE;
    }

    $response_code = $response['code'];

    // Messages should be translatable @codingStandardsIgnoreLine.
    drupal_set_message($this->t($validation_messages[$response_code]), 'error');
  }

}
